pub struct UpdateProjectArgs {
pub id: String,
pub title: Option<String>,
pub notes: Option<String>,
pub when: Option<String>,
pub deadline: Option<String>,
pub tags: Option<Vec<String>>,
pub area_id: Option<String>,
pub completed: Option<bool>,
pub canceled: Option<bool>,
}Fields
id: StringUUID of the project to update.
title: Option<String>notes: Option<String>when: Option<String>deadline: Option<String>None = leave tags unchanged. Some(vec![]) = clear all tags.
area_id: Option<String>completed: Option<bool>canceled: Option<bool>Trait Implementations
Sourceimpl Clone for UpdateProjectArgs
impl Clone for UpdateProjectArgs
Sourcefn clone(&self) -> UpdateProjectArgs
fn clone(&self) -> UpdateProjectArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateProjectArgs
impl Debug for UpdateProjectArgs
Sourceimpl Default for UpdateProjectArgs
impl Default for UpdateProjectArgs
Sourcefn default() -> UpdateProjectArgs
fn default() -> UpdateProjectArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateProjectArgs
impl<'de> Deserialize<'de> for UpdateProjectArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateProjectArgs
impl JsonSchema for UpdateProjectArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateProjectArgs
impl RefUnwindSafe for UpdateProjectArgs
impl Send for UpdateProjectArgs
impl Sync for UpdateProjectArgs
impl Unpin for UpdateProjectArgs
impl UnsafeUnpin for UpdateProjectArgs
impl UnwindSafe for UpdateProjectArgs